# README #

### What is this repository for? ###

A skelington for gsdl2.

### How do I get set up? ###

* Recommended pypy 5.0, cffi, and pycparser. See (http://cffi.readthedocs.org/en/latest/#installation-and-status).
* Summary of set up:
    * (Optional) Install [pypy](http://pypy.org/download.html)
    * Fix environment to use pypy (e.g. set PATH in Windows, or use virtualenv) so that pip will work
    * Install [pip](https://pip.pypa.io/en/latest/installing.html)
    * pip install cffi  (if necessary; it is probably included)
    * pip install pycparser  (if necessary; it is probably included)
    * Install dynamic libraries for [SDL 2.0](https://www.libsdl.org/download-2.0.php), [SDL_image 2.0](https://www.libsdl.org/projects/SDL_image/), [SDL_ttf 2.0](https://www.libsdl.org/projects/SDL_ttf/), and [SDL_mixer 2.0](https://www.libsdl.org/projects/SDL_mixer/). On Windows, for pypy I simply copied *.dll to the C:\pypy25 folder, and for CPython to the C:\Python\DLLs folder. You may need to put the folder in the system path.
* Unpack the following into a working directory
    * [gsdl2](https://bitbucket.org/gummbum/gsdl2)
    * [gsdl2_skel](https://bitbucket.org/gummbum/gsdl2)

The resulting directory structure should look like this:

workdir/
    data/
    gamelib/
        gsdl2/
            *.py    # gsdl2 library
        *.py    # skelington library
    run_game.py
    run_game.pyw
    run_game_debug.py

### Points of interest. ###

There are three front-end game launchers. They are pretty simple.

Command-line args parsing is done in gamelib/settings.py. All configs and runtime objects are stored in this file, too.

Initialization is done in gamelib/main.py, and contexts are loaded.

This design uses a context stack, aka scene stack. There are predefined contexts for Intro, Mainmenu, Game, and Credits.
These are in gamelib/, named contextintro.py, contextmainmenu.py, contextgame.py, and contextcredits.py, respectively.
These inherit from context.Context, and are pushed and popped under the appropriate context switching conditions (e.g.
menu-click, exit, whatever). Contexts are very flexible. They can be reused, or recreated. The Game context can be a
persistent context, or it can tailored to push other contexts, e.g. a multi-level adventure. Contexts are just objects
that come into relevance when they are on the stack. The top context on the stack is accessed by the CPU loop in
context.run. See the context module for transitive stub methods: enter, exit, suspend, resume.

There is a SpatialHash. You probably want to use this if the game will do a lot of collision detection, or have a large
game world with a small viewport. It is very efficient at dealing with high object counts.

There is a TextureSprite, a TextSprite, texture caching, and tweening for convenient visual effects.

The sound module provides a music carousel, music selector, SFX jukebox, and wrapper classes for sounds and channels.

For the model there is a geomoetry module, the ubiquitous Vec2d class, and the aforementioned SpatialHash.

Tbere is an experimental isometric module for converting coordinates between ortho and iso space.

And the pipestdio module provides an interface for managing stdout in real-time.

That is about it. Everything else you do will be with the gsdl2 library, or your customizations. Happy coding.

### Who do I talk to? ###

Gummbum, #pygame on freenode.net or the pygame-users mailing list
