"""intro.py - a context for displaying a splash screen, slideshow, movie, etc.
"""

import random

import gsdl2

import context
import contextmainmenu
import sound
import settings
import text


class Intro(context.Context):
    
    def __init__(self):
        context.Context.__init__(self, gsdl2.time.FixedDriver(self.update, settings.time_step))
        self.clock.new_schedule(self.draw, 1.0 / 120.0)

        self.bgcolor = gsdl2.Color('darkgreen')
        self.renderer = gsdl2.display.get_renderer()
        self.renderer.draw_color = self.bgcolor

        self.font = None
        self.countdown = None
        self.text = None
        self.dx = None
        self.dy = None

        self.sprite = None

    def enter(self):
        sound.play_music(0)
        font_name, font_size = settings.font_info['ui']
        self.font = gsdl2.font.Font(font_name, font_size)
        self.countdown = 10.99999  # float, seconds
        self.text = ''
        self.update_text()
        self.dx = random.choice((-3, -2, -1, 1, 2, 3))
        self.dy = random.choice((-3, -2, -1, 1, 2, 3))

    def update(self, dt):
        self.countdown -= dt
        if int(self.countdown) <= 0:
            self.action_main_menu()
        
        self.update_text()
        screen_rect = settings.screen_rect
        self.sprite.update_pos(self.sprite.pos + (self.dx, self.dy))
        text_rect = self.sprite.rect
        if not screen_rect.contains(self.sprite.rect):
            if text_rect.x < 0 or text_rect.right >= screen_rect.right:
                self.dx *= -1
            if text_rect.y < 0 or text_rect.bottom >= screen_rect.bottom:
                self.dy *= -1

    def update_text(self):
        self.get_events()
        new_text = 'Intro (Wait {0:d} or Click)'.format(int(self.countdown))
        if new_text == self.text:
            return
        self.text = new_text
        pos = self.sprite.pos if self.sprite else (0, 0)
        self.sprite = text.TextSprite(new_text, self.font, gsdl2.Color('white'), pos, anchor='topleft')

    def draw(self, sched):
        interp = sched.interp
        self.renderer.clear()
        self.sprite.draw(self.renderer, interp)
        self.renderer.present()
    
    def action_main_menu(self):
        self.pop()
        self.push(contextmainmenu.MainMenu())
    
    def on_mouse_button_down(self, e):
        self.action_main_menu()

    def on_user_event(self, e):
        if e.code == settings.song_finished:
            if settings.play_music:
                sound.play_music(0)

    def on_quit(self):
        self.pop()
