"""isometric.py - coordinate conversions between orthogonal map and isometric screen

orthogonal map space, tile = 64 x 64
 ----- ----- -----
| 0,0 | 1,0 | 2,0 |
 ----- ----- -----
| 0,1 | 1,1 | 2,1 |
 ----- ----- -----
| 0,2 | 1,2 | 2,2 |
 ----- ----- -----


isometric view space, tile = 64 x 32
- rotate clockwise ==> 45 degrees
- rotate back ^ 30 degrees
         0,0
       0,1  1,0
    0,2  1,1  2,0
       1,2  2,1
         2,2
"""



def m2s(x, y, tilew, tileh):
    """integer convert map to screen coordinates
    """
    return (x - y) * tilew // 2, (x + y) * tileh // 2


def m2sf(x, y, tilew, tileh):
    """float convert map to screen coordinates
    """
    return float(x - y) * tilew / 2, float(x + y) * tileh / 2


def s2m(x, y, tilew, tileh):
    """integer convert screen to map coordinates
    """
    tilew_half = tilew // 2
    tileh_half = tileh // 2
    return (x // tilew_half + y // tileh_half) // 2, (y // tileh_half - (x // tilew_half)) // 2


def s2mf(x, y, tilew, tileh):
    """float convert screen to map coordinates
    """
    return x / tilew + y / tileh, y / tileh - x / tilew


def c2m(camera_rect):
    """integer convert camera to map coordinates
    """
    camera_rect = camera_rect.inflate(0, camera_rect.h)
    x, y = camera_rect.topleft
    tl = x - x // 2, y + y // 2
    x, y = camera_rect.topright
    tr = x - x // 2, y - y // 2
    x, y = camera_rect.bottomright
    br = x + x // 2, y - y // 2
    x, y = camera_rect.bottomlef
    bl = x + x // 2, y + y // 2
    return tl, tr, br, bl


def c2mf(camera_rect):
    """float convert camera to map coordinates
    """
    camera_rect = camera_rect.inflate(0, camera_rect.h)
    two = 2.0
    x, y = camera_rect.topleft
    tl = x - x / two, y + y / two
    x, y = camera_rect.topright
    tr = x - x / two, y - y / two
    x, y = camera_rect.bottomright
    br = x + x / two, y - y / two
    x, y = camera_rect.bottomlef
    bl = x + x / two, y + y / two
    return tl, tr, br, bl
