"""
Keyboard controls:
    e = advance: ellipse type
    f = toggle: draw frame or shape
"""

import os
import sys


appdir = os.path.abspath(os.path.dirname(__file__))
os.chdir(appdir)
appdir = '/'.join((appdir, '../gamelib'))
if appdir not in sys.path:
    sys.path.insert(0, appdir)

import gsdl2

import geometry


gsdl2.init()
gsdl2.display.set_mode((1024, 768))
renderer = gsdl2.display.get_renderer()
clock = gsdl2.Clock()

green = gsdl2.Color('green')
red = gsdl2.Color('red')
grey = gsdl2.Color('grey')
# TODO: report the bugs in ellipse() and aaellipse() w/ the following shape
# TODO: ellipse = geometry.EllipseGeometry((500, 500), 200, 25)
ellipses = [
    (75, 25),
    (25, 75),
    (75, 75),
]
ellipse = geometry.EllipseGeometry((500, 500), *ellipses[0], position=(950, 50))
circles = [
    geometry.CircleGeometry((200, 100), 15),
    geometry.CircleGeometry((200, 250), 35),
    geometry.CircleGeometry((200, 550), 100),
]
rects = [
    geometry.RectGeometry(0, 0, 25, 25, position=(450, 100)),
    geometry.RectGeometry(0, 0, 75, 75, position=(450, 250)),
    geometry.RectGeometry(0, 0, 175, 175, position=(450, 550)),
]
lines = [
    geometry.LineGeometry(600, 75, 650, 120),
    geometry.LineGeometry(600, 225, 650, 350),
    geometry.LineGeometry(600, 450, 650, 700),
]
polys = [
    geometry.PolyGeometry(([0, 0], [25, 25], [0, 25]), position=(800, 100)),
    geometry.PolyGeometry(([0, 0], [50, 50], [0, 50]), position=(800, 250)),
    geometry.PolyGeometry(([150, 0], [300, 300], [0, 300]), position=(700, 400)),
]
draw_frame = 1

tick = 0
fps = 30

while True:
    clock.tick(fps)
    tick += 1
    if tick % fps == 0:
        gsdl2.display.set_caption('{} fps | Draw ellipse: {}'.format(
            clock.get_fps(), 'frame' if draw_frame else 'true shape'))

    for e in gsdl2.event.get():
        if e.type == gsdl2.MOUSEMOTION:
            ellipse.position = e.pos
        elif e.type == gsdl2.KEYDOWN:
            if e.scancode == gsdl2.S_E:
                rad = ellipses.pop(0)
                ellipses.append(rad)
                radx, rady = ellipses[0]
                ellipse.radius_x = radx
                ellipse.radius_y = rady
            elif e.scancode == gsdl2.S_F:
                draw_frame = not draw_frame
            elif e.scancode == gsdl2.S_ESCAPE:
                quit()
        elif e.type == gsdl2.QUIT:
            quit()

    # detect collisions

    ellipse.color = green
    ellipse_plot = ellipse.plot(15)
    ellipse_collided = ellipse.collided
    if False:
        # these test the collision primitives
        for circle in circles:
            circle.color = green
            if geometry.ellipse_intersects_circle(
                    ellipse.position, ellipse.radius_x, ellipse.radius_y, ellipse_plot, circle.origin, circle.radius):
                circle.color = ellipse.color = red
        for rect in rects:
            rect.color = green
            if geometry.ellipse_intersects_rect(ellipse_plot, rect.rect):
                rect.color = ellipse.color = red
        for line in lines:
            line.color = green
            if geometry.ellipse_intersects_line(ellipse_plot, line.points):
                line.color = ellipse.color = red
        for poly in polys:
            poly.color = green
            if geometry.ellipse_intersects_poly(ellipse.origin, ellipse_plot, poly.points):
                poly.color = ellipse.color = red
    elif False:
        # these test the ellipse_collided_other wrapper
        for group in circles, rects, lines, polys:
            for obj in group:
                obj.color = green
                if ellipse_collided(ellipse, obj):
                    obj.color = ellipse.color = red
    else:
        # these test the *_collided_other wrappers
        for circle in circles:
            circle.color = green
            if geometry.circle_collided_other(circle, ellipse):
                circle.color = ellipse.color = red
        for rect in rects:
            rect.color = green
            if geometry.rect_collided_other(rect, ellipse):
                rect.color = ellipse.color = red
        for line in lines:
            line.color = green
            if geometry.line_collided_other(line, ellipse):
                line.color = ellipse.color = red
        for poly in polys:
            poly.color = green
            if geometry.poly_collided_other(poly, ellipse):
                poly.color = ellipse.color = red

    # draw shapes

    renderer.clear()
    if draw_frame:
        # draw ellipse approximation
        gsdl2.gfx.polygon(renderer, ellipse.plot(10), grey)
    else:
        # draw ellipse
        gsdl2.gfx.ellipse(
            renderer, ellipse.position.x, ellipse.position.y, ellipse.radius_x, ellipse.radius_y, ellipse.color)
    # draw circles
    for circle in circles:
        gsdl2.gfx.aacircle(renderer, circle.origin.x, circle.origin.y, circle.radius, circle.color)
    # draw rects
    for rect in rects:
        gsdl2.gfx.rectangle(renderer, rect.rect, rect.color)
    # draw lines
    for line in lines:
        gsdl2.gfx.line(renderer, line.p1, line.p2, line.color)
    # draw polygons
    for poly in polys:
        gsdl2.gfx.polygon(renderer, poly.points, poly.color)
    renderer.present()
